@@ -9,21 +9,22 @@ import click
 
 from ..client.gas import DatasetClientType
 from .tbrn import TBRN, TBRNType
-from .utility import ContextInfo, error, get_dataset_client, get_gas, shorten
+from .utility import ContextInfo, error, exception_handler, get_dataset_client, shorten
 
 
+@exception_handler
 def _implement_branch(
     obj: ContextInfo, tbrn: str, name: str, verbose: bool, is_delete: bool
 ) -> None:
-    info = TBRN(tbrn=tbrn)
-    if info.type != TBRNType.DATASET:
-        error(f'To operate a branch, "{info}" must be a dataset')
+    tbrn_info = TBRN(tbrn=tbrn)
+    if tbrn_info.type != TBRNType.DATASET:
+        error(f'To operate a branch, "{tbrn_info}" must be a dataset')
 
-    gas = get_gas(*obj)
-    dataset_client = get_dataset_client(gas, info)
+    gas = obj.get_gas()
+    dataset_client = get_dataset_client(gas, tbrn_info)
 
     if is_delete:
-        _delete_branch(dataset_client, info)
+        _delete_branch(dataset_client, tbrn_info)
         return
 
     if name:
@@ -36,12 +37,9 @@ def _create_branch(dataset_client: DatasetClientType, name: str) -> None:
     if dataset_client.status.is_draft:
         error("Branch cannot be created from a draft")
 
-    if not dataset_client.status.commit_id:
-        error(f'To create a branch, "{dataset_client.name}" must have commit history')
-
     dataset_client.create_branch(name)
-    branch_tbrn = TBRN(dataset_client.name, revision=name)
-    click.echo(f"{branch_tbrn} has been successfully created")
+    branch_tbrn = TBRN(dataset_client.name, revision=name).get_colored_tbrn()
+    click.echo(f'Successfully created branch "{branch_tbrn}"')
 
 
 def _list_branches(dataset_client: DatasetClientType, verbose: bool) -> None:
@@ -55,9 +53,9 @@ def _list_branches(dataset_client: DatasetClientType, verbose: bool) -> None:
             click.echo(f"{branch.name:{name_length}} {shorten(branch.commit_id)} {branch.title}")
 
 
-def _delete_branch(dataset_client: DatasetClientType, info: TBRN) -> None:
-    if not info.revision:
-        error(f'To delete a branch, "{info}" must have a branch name')
+def _delete_branch(dataset_client: DatasetClientType, tbrn_info: TBRN) -> None:
+    if not tbrn_info.revision:
+        error(f'To delete a branch, "{tbrn_info.get_tbrn()}" must have a branch name')
 
-    dataset_client._delete_branch(info.revision)  # pylint: disable=protected-access
-    click.echo(f"{info} has been successfully deleted")
+    dataset_client._delete_branch(tbrn_info.revision)  # pylint: disable=protected-access
+    click.echo(f'Successfully deleted branch "{tbrn_info.get_colored_tbrn()}"')
