@@ -5,29 +5,15 @@
 
 """Implementation of gas config."""
 
-import sys
-
 import click
 
-from .utility import error, is_accesskey, read_config, update_config, write_config
+from .utility import ContextInfo, error
 
 
-def _implement_config(key: str, value: str, unset: bool) -> None:
+def _implement_config(obj: ContextInfo, key: str, value: str, unset: bool) -> None:
     _check_args_and_options(key, value, unset)
 
-    update_config()
-    config_parser = read_config()
-
-    if is_accesskey(key):
-        click.secho(
-            "DeprecationWarning: Setting AccessKey in 'gas config'"
-            " is deprecated since version v1.7.0. "
-            "It will be removed in version v1.9.0. "
-            "Use 'gas auth Accesskey' instead.",
-            fg="red",
-            err=True,
-        )
-        sys.exit(1)
+    config_parser = obj.config_parser
 
     if not config_parser.has_section("config"):
         config_parser.add_section("config")
@@ -43,14 +29,15 @@ def _implement_config(key: str, value: str, unset: bool) -> None:
             error(f"{key} has not been configured yet")
         if unset:
             del config_section[key]
-            write_config(config_parser, show_message=False)
-            click.echo(f'Unset "{key}" successfully')
+            obj.write_config(show_message=False)
+            click.echo(f'Successfully unset "{key}"')
             return
 
         click.echo(f"{key} = {config_section[key]}\n")
     else:
+        _check_key_and_value(key, value)
         config_section[key] = value
-        write_config(config_parser)
+        obj.write_config()
 
 
 def _check_args_and_options(key: str, value: str, unset: bool) -> None:
@@ -59,6 +46,14 @@ def _check_args_and_options(key: str, value: str, unset: bool) -> None:
             error('Use "--unset" option to unset config or use "key" and "value" to set config')
         if not key:
             error('Use "--unset" option with "key"')
+    if key not in {"editor", "timeout", "is_internal", "max_retries", ""}:
+        error(f'The option "{key}" is not supported to configure currently.')
 
-    if key and key != "editor":
-        error(f'The option "{key}" is not supported to configure currently.\n')
+
+def _check_key_and_value(key: str, value: str) -> None:
+    if key in {"timeout", "max_retries"}:
+        if not value.isdigit():
+            error(f'The option "{key}" need integer value.')
+    elif key == "is_internal":
+        if value.lower() not in {"true", "false", "0", "1"}:
+            error('The option "is_internal" need True(1) or False(0) value.')
