@@ -4,10 +4,11 @@
 #
 
 """Implementation of gas log."""
+
 import bisect
 from collections import defaultdict
 from datetime import datetime
-from itertools import islice, zip_longest
+from itertools import cycle, islice, zip_longest
 from textwrap import indent
 from typing import DefaultDict, Dict, Iterator, List, Optional, Type, Union
 
@@ -17,31 +18,53 @@ from ..client.gas import DatasetClientType
 from ..client.struct import Commit
 from .auth import INDENT
 from .tbrn import TBRN, TBRNType
-from .utility import error, get_gas, is_win, shorten
+from .utility import ContextInfo, error, exception_handler, is_win, shorten
 
-_FULL_LOG = """commit {}
-Author: {}
-Date: {}
+_LEFT_BRACKET = click.style("(", fg="yellow", reset=False)
+_COMMA = click.style(", ", fg="yellow", reset=False)
+_RIGHT_BRACKET = click.style(")", fg="yellow", reset=True)
 
-    {}
+_FULL_LOG = f"""{click.style("commit {}", fg="yellow")}
+Author: {{}}
+Date: {{}}
+
+    {{}}
 """
 
+_ONELINE_LOG = f"""{click.style("{}", fg="yellow")} {{}}
+"""
 
+_LOG_COLORS = (
+    "red",
+    "green",
+    "blue",
+    "magenta",
+    "cyan",
+    "bright_blue",
+    "bright_magenta",
+    "bright_cyan",
+    "bright_red",
+    "bright_green",
+    "bright_yellow",
+)
+
+
+@exception_handler
 def _implement_log(  # pylint: disable=too-many-arguments
-    obj: Dict[str, str],
+    obj: ContextInfo,
     tbrn: str,
     max_count: Optional[int],
     oneline: bool,
     is_all: bool,
     graph: bool,
 ) -> None:
-    gas = get_gas(**obj)
-    info = TBRN(tbrn=tbrn)
-    if info.type != TBRNType.DATASET:
-        error(f'To log commits, "{info}" must be a dataset')
+    gas = obj.get_gas()
+    tbrn_info = TBRN(tbrn=tbrn)
+    if tbrn_info.type != TBRNType.DATASET:
+        error(f'To log commits, "{tbrn}" must be a dataset')
 
     dataset_client = gas._get_dataset_with_any_type(  # pylint: disable=protected-access
-        info.dataset_name
+        tbrn_info.dataset_name
     )
     commit_id_to_branches: DefaultDict[str, List[str]] = defaultdict(list)
     for branch in dataset_client.list_branches():
@@ -49,7 +72,9 @@ def _implement_log(  # pylint: disable=too-many-arguments
     if is_all:
         revisions: List[Optional[str]] = [branch.name for branch in dataset_client.list_branches()]
     else:
-        revisions = [info.revision] if info.revision else [dataset_client.status.branch_name]
+        revisions = (
+            [tbrn_info.revision] if tbrn_info.revision else [dataset_client.status.branch_name]
+        )
 
     Printer: Union[Type[_GraphPrinter], Type[_CommitPrinter]] = (
         _GraphPrinter if graph else _CommitPrinter
@@ -65,21 +90,29 @@ def _implement_log(  # pylint: disable=too-many-arguments
         click.echo_via_pager(commit_generator)
 
 
-def _get_oneline_log(commit: Commit, branch_name: Optional[str]) -> str:
+def _join_branch_names(commit_id: str, branch_names: List[str]) -> str:
+    return (
+        f"{commit_id} {_LEFT_BRACKET}"
+        f"{_COMMA.join(click.style(name, fg='green', reset=False) for name in branch_names)}"
+        f"{_RIGHT_BRACKET}"
+    )
+
+
+def _get_oneline_log(commit: Commit, branch_names: Optional[List[str]]) -> str:
     commit_id = shorten(commit.commit_id)
-    if branch_name:
-        commit_id = f"{commit_id} ({branch_name})"
-    return f"{commit_id} {commit.title}\n"
+    if branch_names:
+        commit_id = _join_branch_names(commit_id, branch_names)
+    return _ONELINE_LOG.format(commit_id, commit.title)
 
 
-def _get_full_log(commit: Commit, branch_name: Optional[str]) -> str:
+def _get_full_log(commit: Commit, branch_names: Optional[List[str]]) -> str:
     description = commit.description
     if description:
         description = f"\n\n{indent(description, INDENT)}"
     commit_message = f"{commit.title}{description}\n"
     commit_id = commit.commit_id
-    if branch_name:
-        commit_id = f"{commit_id} ({branch_name})"
+    if branch_names:
+        commit_id = _join_branch_names(commit_id, branch_names)
     return _FULL_LOG.format(
         commit_id,
         commit.committer.name,
@@ -88,7 +121,7 @@ def _get_full_log(commit: Commit, branch_name: Optional[str]) -> str:
     )
 
 
-class _CommitPrinter:  # pylint: disable=too-few-public-methods
+class _CommitPrinter:
     """This class defines the structure of logging commits.
 
     Arguments:
@@ -181,11 +214,10 @@ class _CommitPrinter:  # pylint: disable=too-few-public-methods
         """
         for commit in self._generate_commits():
             commit_id = commit.commit_id
-            print_branch_name = ", ".join(self._commit_id_to_branches.get(commit_id, ()))
-            yield self._printer(commit, print_branch_name)
+            yield self._printer(commit, self._commit_id_to_branches.get(commit_id))
 
 
-class _CommitNode:  # pylint: disable=too-few-public-methods
+class _CommitNode:
     """This class defines the tree struct of graphical logging commits.
 
     Arguments:
@@ -211,7 +243,7 @@ class _CommitNode:  # pylint: disable=too-few-public-methods
         self.available_child_num += 1
 
 
-class _GraphPrinter:  # pylint: disable=too-few-public-methods
+class _GraphPrinter:
     """This class defines the structure of logging graphical commits stack.
 
     Arguments:
@@ -233,9 +265,10 @@ class _GraphPrinter:  # pylint: disable=too-few-public-methods
         self._graph_printer = self._add_graph_oneline if oneline else self._add_graph_full
 
         self._sorted_leaves = self._build_commit_tree(dataset_client, revisions)
-        self._layer = 1
         self._pointer = 0
         self._merge_pointer: Optional[int] = None
+        self._log_colors = cycle(_LOG_COLORS)
+        self._layer_colors: List[str] = [next(self._log_colors)]
 
     def _get_log_node(self) -> _CommitNode:
         """Get the next log commit node.
@@ -253,29 +286,21 @@ class _GraphPrinter:  # pylint: disable=too-few-public-methods
                 return log_node
 
             self._pointer += 1
-            if self._pointer >= self._layer:
-                self._layer += 1
+            if self._pointer >= len(self._layer_colors):
+                self._layer_colors.append(next(self._log_colors))
 
         raise RuntimeError("Graphical logging algorithm error.")
 
-    def _merge_branches(self, parent: Optional[_CommitNode]) -> int:
+    def _merge_branches(self, parent: _CommitNode) -> None:
         """Merge branches.
 
         Arguments:
             parent: The parent node.
 
-        Returns:
-            The original print pointer.
-
         """
-        if parent not in self._sorted_leaves:
-            return self._pointer
         index = self._sorted_leaves.index(parent)
-        original_pointer = self._pointer
         self._pointer, self._merge_pointer = sorted((index, self._pointer))
-        self._layer -= 1
         del self._sorted_leaves[self._merge_pointer]
-        return original_pointer
 
     def _set_next_node(self, node: _CommitNode) -> None:
         """Set the next node at the position of the printing pointer.
@@ -288,45 +313,50 @@ class _GraphPrinter:  # pylint: disable=too-few-public-methods
         self._sorted_leaves[self._pointer] = node
 
     def _add_graph_oneline(
-        self, commit: Commit, branch_name: Optional[str], original_pointer: int
+        self, commit: Commit, branch_names: Optional[List[str]], original_pointer: int
     ) -> str:
-        log = _get_oneline_log(commit, branch_name)
-        prefixes = ["|"] * self._layer
+        log = _get_oneline_log(commit, branch_names)
+        prefixes = self._get_colorful_prefixes()
         # Don't merge branches.
         if self._merge_pointer is None:
             return f"{self._get_title_prefix(prefixes, original_pointer)} {log}"
 
         # Merge branches.
-        prefixes.append("|")
+        del self._layer_colors[self._merge_pointer]
         lines = [f"{self._get_title_prefix(prefixes, original_pointer)} {log}"]
         lines.extend(f"{prefixes}\n" for prefixes in self._get_merge_prefixes())
         return "".join(lines)
 
     def _add_graph_full(
-        self, commit: Commit, branch_name: Optional[str], original_pointer: int
+        self, commit: Commit, branch_names: Optional[List[str]], original_pointer: int
     ) -> str:
-        log = _get_full_log(commit, branch_name)
+        log = _get_full_log(commit, branch_names)
         splitlines = iter(log.splitlines())
-        prefixes = ["|"] * self._layer
+        prefixes = self._get_colorful_prefixes()
+        lines = [f"{self._get_title_prefix(prefixes, original_pointer)} {next(splitlines)}\n"]
         # Don't merge branches.
         if self._merge_pointer is None:
             details_prefix = " ".join(prefixes)
-            lines = [f"{self._get_title_prefix(prefixes, original_pointer)} {next(splitlines)}\n"]
             lines.extend(f"{details_prefix} {line}\n" for line in splitlines)
         else:
             # Merge branches.
-            prefixes.append("|")
+            del self._layer_colors[self._merge_pointer]
             merge_prefixes = self._get_merge_prefixes()
-            lines = [f"{self._get_title_prefix(prefixes, original_pointer)} {next(splitlines)}\n"]
             lines.extend(self._combine_details(list(merge_prefixes), list(splitlines)))
-
         return "".join(lines)
 
+    def _get_colorful_prefixes(self) -> List[str]:
+        return [click.style("|", fg=color) for color in self._layer_colors]
+
     def _get_merge_prefixes(self) -> Iterator[str]:
+        prefixes = []
+        for color in self._layer_colors:
+            prefixes.append(click.style("|", fg=color))
+            prefixes.append(" ")
         for i in range(self._merge_pointer, self._pointer, -1):  # type: ignore[arg-type]
-            prefixes = ["| "] * self._layer
-            prefixes[i - 1] = "|/"
-            yield "".join(prefixes)
+            temp_prefixes = prefixes.copy()
+            temp_prefixes[2 * i - 1] = click.style("/", fg=self._layer_colors[self._pointer])
+            yield "".join(temp_prefixes)
 
     @staticmethod
     def _get_title_prefix(prefixes: List[str], original_pointer: int) -> str:
@@ -380,16 +410,25 @@ class _GraphPrinter:  # pylint: disable=too-few-public-methods
             The graphical commit log.
 
         """
+        change_color = False
         while True:
             current_node = self._get_log_node()
             parent = current_node.parent
-            # Merge branch.
-            original_pointer = self._merge_branches(parent)
-
-            print_branch_name = ", ".join(
-                self._commit_id_to_branches.get(current_node.commit.commit_id, ())
+            original_pointer = self._pointer
+            if parent not in self._sorted_leaves:
+                if change_color:
+                    # pylint: disable=stop-iteration-return
+                    self._layer_colors[self._pointer] = next(self._log_colors)
+                    change_color = False
+            else:
+                # Merge branch.
+                change_color = True
+                self._merge_branches(parent)
+            yield self._graph_printer(
+                current_node.commit,
+                self._commit_id_to_branches.get(current_node.commit.commit_id),
+                original_pointer,
             )
-            yield self._graph_printer(current_node.commit, print_branch_name, original_pointer)
 
             if not parent:
                 break
