@@ -25,19 +25,17 @@ Please refer to :class:`~tensorbay.dataset.dataset.FusionDataset` for more infor
 import logging
 from typing import TYPE_CHECKING, Any, Dict, Generator, Iterable, Iterator, Optional, Tuple, Union
 
+from ulid import ULID, from_timestamp
+
 from ..dataset import AuthData, Data, Frame, FusionSegment, Notes, RemoteData, Segment
-from ..exception import (
-    FrameError,
-    InvalidParamsError,
-    NameConflictError,
-    OperationError,
-    ResourceNotExistError,
-)
+from ..exception import FrameError, InvalidParamsError, NameConflictError, ResourceNotExistError
 from ..label import Catalog
+from .diff import DataDiff, DatasetDiff, SegmentDiff
 from .lazy import PagingList
 from .log import UPLOAD_SEGMENT_RESUME_TEMPLATE
 from .requests import Tqdm, multithread_upload
 from .segment import _STRATEGIES, FusionSegmentClient, SegmentClient
+from .statistics import Statistics
 from .status import Status
 from .version import VersionControlClient
 
@@ -60,6 +58,8 @@ class DatasetClientBase(VersionControlClient):
         dataset_id: Dataset ID.
         gas: The initial client to interact between local and TensorBay.
         status: The version control status of the dataset.
+        alias: Dataset alias.
+        is_public: Whether the dataset is public.
 
     Attributes:
         name: Dataset name.
@@ -68,9 +68,20 @@ class DatasetClientBase(VersionControlClient):
 
     """
 
-    def __init__(self, name: str, dataset_id: str, gas: "GAS", *, status: Status) -> None:
+    def __init__(
+        self,
+        name: str,
+        dataset_id: str,
+        gas: "GAS",
+        *,
+        status: Status,
+        alias: str,
+        is_public: bool,
+    ) -> None:
         super().__init__(dataset_id, gas, status=status)
         self._name = name
+        self._alias = alias
+        self._is_public = is_public
 
     def _create_segment(self, name: str) -> None:
         post_data: Dict[str, Any] = {"name": name}
@@ -111,7 +122,7 @@ class DatasetClientBase(VersionControlClient):
 
         if not source_client:
             if source_name == target_name:
-                raise OperationError("Copying the segment to the same location is not allowed")
+                raise ValueError("Copying the segment to the same location is not allowed")
         else:
             source["id"] = source_client.dataset_id
             source.update(source_client.status.get_status_info())
@@ -127,6 +138,25 @@ class DatasetClientBase(VersionControlClient):
 
         self._client.open_api_do("POST", "segments?copy", self._dataset_id, json=post_data)
 
+    def _move_segment(
+        self,
+        source_name: str,
+        target_name: str,
+        *,
+        strategy: str = "abort",
+    ) -> None:
+        self._status.check_authority_for_draft()
+        if strategy not in _STRATEGIES:
+            raise InvalidParamsError(param_name="strategy", param_value=strategy)
+        post_data: Dict[str, Any] = {
+            "strategy": strategy,
+            "source": {"segmentName": source_name},
+            "segmentName": target_name,
+        }
+        post_data.update(self._status.get_status_info())
+
+        self._client.open_api_do("POST", "segments?move", self._dataset_id, json=post_data)
+
     @property
     def name(self) -> str:
         """Return the TensorBay dataset name.
@@ -137,6 +167,26 @@ class DatasetClientBase(VersionControlClient):
         """
         return self._name
 
+    @property
+    def alias(self) -> str:
+        """Return the TensorBay dataset alias.
+
+        Returns:
+            The TensorBay dataset alias.
+
+        """
+        return self._alias
+
+    @property
+    def is_public(self) -> bool:
+        """Return whether the dataset is public.
+
+        Returns:
+            Whether the dataset is public.
+
+        """
+        return self._is_public
+
     def update_notes(
         self,
         *,
@@ -207,15 +257,10 @@ class DatasetClientBase(VersionControlClient):
         Arguments:
             catalog: :class:`~tensorbay.label.catalog.Catalog` to upload.
 
-        Raises:
-            TypeError: When the catalog is empty.
-
         """
         self._status.check_authority_for_draft()
 
         put_data: Dict[str, Any] = {"catalog": catalog.dumps()}
-        if not put_data:
-            raise TypeError("Empty catalog")
         put_data.update(self._status.get_status_info())
 
         self._client.open_api_do("PUT", "labels/catalogs", self._dataset_id, json=put_data)
@@ -234,6 +279,20 @@ class DatasetClientBase(VersionControlClient):
 
         self._client.open_api_do("DELETE", "segments", self._dataset_id, json=delete_data)
 
+    def get_label_statistics(self) -> Statistics:
+        """Get label statistics of the dataset.
+
+        Returns:
+            Required :class:`~tensorbay.client.dataset.Statistics`.
+
+        """
+        params: Dict[str, Any] = self._status.get_status_info()
+        return Statistics(
+            self._client.open_api_do(
+                "GET", "labels/statistics", self._dataset_id, params=params
+            ).json()["labelStatistics"]
+        )
+
 
 class DatasetClient(DatasetClientBase):
     """This class defines :class:`DatasetClient`.
@@ -261,6 +320,43 @@ class DatasetClient(DatasetClientBase):
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
+    def _generate_segment_diffs(
+        self, basehead: str, offset: int = 0, limit: int = 128
+    ) -> Generator[SegmentDiff, None, int]:
+        params: Dict[str, Any] = {"offset": offset, "limit": limit}
+
+        response = self._client.open_api_do(
+            "GET", f"diffs/{basehead}/segments", self._dataset_id, params=params
+        ).json()
+
+        for segment_diff_response in response["segments"]:
+            segment_name = segment_diff_response["name"]
+            data_diffs = self._list_data_diffs(basehead, segment_name)
+            segment_diff = SegmentDiff(segment_name, segment_diff_response["action"], data_diffs)
+            yield segment_diff
+
+        return response["totalCount"]  # type: ignore[no-any-return]
+
+    def _generate_data_diffs(
+        self, basehead: str, segment_name: str, offset: int = 0, limit: int = 128
+    ) -> Generator[DataDiff, None, int]:
+        params: Dict[str, Any] = {"offset": offset, "limit": limit}
+
+        response = self._client.open_api_do(
+            "GET", f"diffs/{basehead}/segments/{segment_name}/data", self._dataset_id, params=params
+        ).json()
+
+        for data in response["data"]:
+            yield DataDiff.loads(data)
+
+        return response["totalCount"]  # type: ignore[no-any-return]
+
+    def _list_data_diffs(self, basehead: str, segment_name: str) -> PagingList[DataDiff]:
+        return PagingList(
+            lambda offset, limit: self._generate_data_diffs(basehead, segment_name, offset, limit),
+            128,
+        )
+
     def _list_segment_instances(self) -> PagingList[Segment]:
         return PagingList(self._generate_segments, 128)
 
@@ -387,21 +483,8 @@ class DatasetClient(DatasetClientBase):
         Returns:
             The client of the moved target segment.
 
-        Raises:
-            InvalidParamsError: When the strategy is invalid.
-
         """
-        self._status.check_authority_for_draft()
-        if strategy not in _STRATEGIES:
-            raise InvalidParamsError(param_name="strategy", param_value=strategy)
-        post_data: Dict[str, Any] = {
-            "strategy": strategy,
-            "source": {"segmentName": source_name},
-            "segmentName": target_name,
-        }
-        post_data.update(self._status.get_status_info())
-
-        self._client.open_api_do("POST", "segments?move", self._dataset_id, json=post_data)
+        self._move_segment(source_name, target_name, strategy=strategy)
         return SegmentClient(target_name, self)
 
     def get_segment(self, name: str = "default") -> SegmentClient:
@@ -411,7 +494,7 @@ class DatasetClient(DatasetClientBase):
             name: The name of the required segment.
 
         Returns:
-            The required class:`~tensorbay.client.segment.SegmentClient`.
+            The required :class:`~tensorbay.client.segment.SegmentClient`.
 
         Raises:
             ResourceNotExistError: When the required segment does not exist.
@@ -470,6 +553,33 @@ class DatasetClient(DatasetClientBase):
             )
             raise
 
+    def get_diff(self, *, head: Optional[Union[str, int]] = None) -> DatasetDiff:
+        """Get a brief diff between head and its parent commit.
+
+        Arguments:
+            head: Target version identification. Type int for draft number, type str for revision.
+                If not given, use the current commit id.
+
+        Examples:
+            >>> self.get_diff(head="b382450220a64ca9b514dcef27c82d9a")
+
+        Returns:
+            The brief diff between head and its parent commit.
+
+        """
+        basehead = self._get_basehead(None, head)
+
+        segment_diffs = PagingList(
+            lambda offset, limit: self._generate_segment_diffs(basehead, offset, limit), 128
+        )
+
+        dataset_diff = DatasetDiff(self.name, segment_diffs)
+
+        return dataset_diff
+
+
+FrameDataGenerator = Iterator[Tuple[Union[Data, AuthData], str, str]]
+
 
 class FusionDatasetClient(DatasetClientBase):
     """This class defines :class:`FusionDatasetClient`.
@@ -485,22 +595,40 @@ class FusionDatasetClient(DatasetClientBase):
     """
 
     @staticmethod
-    def _skip_upload_frame(
-        segment_filter: Iterator[Tuple[Frame, Optional[float], bool]],
-        done_set: Dict[float, Frame],
+    def _extract_all_data(
+        source_frames: Iterator[Tuple[Frame, ULID]],
         pbar: Tqdm,
-    ) -> Iterator[Tuple[Frame, Optional[float], bool]]:
-        for frame, timestamp, _ in segment_filter:
-            if timestamp is None:
-                timestamp = frame.frame_id.timestamp().timestamp
-            remote_frame = done_set.get(timestamp)
-            if remote_frame is None:
-                yield frame, timestamp, False
-            elif len(frame) != len(remote_frame):
-                frame.frame_id = remote_frame.frame_id
-                yield frame, None, True
-            else:
-                pbar.update()
+    ) -> FrameDataGenerator:
+        for frame, frame_id in source_frames:
+            for sensor_name, data in frame.items():
+                if isinstance(data, RemoteData):
+                    pbar.update()
+                    continue
+
+                yield data, sensor_name, frame_id.str
+
+    @staticmethod
+    def _extract_unuploaded_data(
+        source_frames: Iterator[Tuple[Frame, ULID]], pbar: Tqdm, *, done_frames: Dict[float, Frame]
+    ) -> FrameDataGenerator:
+        for frame, frame_id in source_frames:
+            done_frame = done_frames.get(frame_id.timestamp().timestamp)
+            if done_frame:
+                frame_id = done_frame.frame_id
+            for sensor_name, data in frame.items():
+                if isinstance(data, RemoteData):
+                    pbar.update()
+                    continue
+
+                if (
+                    done_frame
+                    and sensor_name in done_frame
+                    and done_frame[sensor_name].path == data.target_remote_path
+                ):
+                    pbar.update()
+                    continue
+
+                yield data, sensor_name, frame_id.str
 
     def _generate_segments(
         self, offset: int = 0, limit: int = 128
@@ -531,36 +659,40 @@ class FusionDatasetClient(DatasetClientBase):
         for sensor in segment.sensors:
             segment_client.upload_sensor(sensor)
 
-        segment_filter: Iterator[Tuple[Frame, Optional[float], bool]]
-
         if not segment:
             return segment_client
 
         have_frame_id = hasattr(segment[0], "frame_id")
 
         for frame in segment:
-            if not hasattr(frame, "frame_id") == have_frame_id:
+            if hasattr(frame, "frame_id") != have_frame_id:
                 raise FrameError(
                     "All the frames should have the same patterns(all have frame id or not)."
                 )
 
         if have_frame_id:
-            segment_filter = ((frame, None, False) for frame in segment)
+            source_frames = ((frame, frame.frame_id) for frame in segment)
         else:
-            segment_filter = (
-                (frame, 10 * index + 10, False) for index, frame in enumerate(segment)
+            source_frames = (
+                (frame, from_timestamp(10 * index + 10)) for index, frame in enumerate(segment)
             )
 
-        if skip_uploaded_files:
-            done_set = {
+        if not skip_uploaded_files:
+            data_to_upload = FusionDatasetClient._extract_all_data(source_frames, pbar)
+        else:
+            done_frames: Dict[float, Frame] = {
                 frame.frame_id.timestamp().timestamp: frame
                 for frame in segment_client.list_frames()
             }
-            segment_filter = self._skip_upload_frame(segment_filter, done_set, pbar)
+            data_to_upload = FusionDatasetClient._extract_unuploaded_data(
+                source_frames, pbar, done_frames=done_frames
+            )
 
         multithread_upload(
-            lambda args: segment_client.upload_frame(*args),
-            segment_filter,
+            # pylint: disable=protected-access
+            lambda args: segment_client._upload_or_import_data(*args),
+            data_to_upload,
+            callback=segment_client._synchronize_upload_info,
             jobs=jobs,
             pbar=pbar,
         )
@@ -658,21 +790,8 @@ class FusionDatasetClient(DatasetClientBase):
         Returns:
             The client of the moved target segment.
 
-        Raises:
-            InvalidParamsError: When the strategy is invalid.
-
         """
-        self._status.check_authority_for_draft()
-        if strategy not in _STRATEGIES:
-            raise InvalidParamsError(param_name="strategy", param_value=strategy)
-        post_data: Dict[str, Any] = {
-            "strategy": strategy,
-            "source": {"segmentName": source_name},
-            "segmentName": target_name,
-        }
-        post_data.update(self._status.get_status_info())
-
-        self._client.open_api_do("POST", "segments?move", self._dataset_id, json=post_data)
+        self._move_segment(source_name, target_name, strategy=strategy)
         return FusionSegmentClient(target_name, self)
 
     def get_segment(self, name: str = "default") -> FusionSegmentClient:
@@ -682,7 +801,7 @@ class FusionDatasetClient(DatasetClientBase):
             name: The name of the required fusion segment.
 
         Returns:
-            The required class:`~tensorbay.client.segment.FusionSegmentClient`.
+            The required :class:`~tensorbay.client.segment.FusionSegmentClient`.
 
         Raises:
             ResourceNotExistError: When the required fusion segment does not exist.
@@ -725,7 +844,7 @@ class FusionDatasetClient(DatasetClientBase):
         """
         self._status.check_authority_for_draft()
         try:
-            with Tqdm(len(segment), disable=quiet) as pbar:
+            with Tqdm(sum(len(frame) for frame in segment), disable=quiet) as pbar:
                 return self._upload_segment(
                     segment, jobs=jobs, skip_uploaded_files=skip_uploaded_files, pbar=pbar
                 )
