@@ -19,7 +19,7 @@ from typing import Any, Dict, Generator, Optional, Type, Union, overload
 from typing_extensions import Literal
 
 from ..dataset import Dataset, FusionDataset
-from ..exception import DatasetTypeError, OperationError, ResourceNotExistError
+from ..exception import DatasetTypeError, ResourceNotExistError
 from ..utility import Deprecated
 from .cloud_storage import CloudClient
 from .dataset import DatasetClient, FusionDatasetClient
@@ -598,7 +598,7 @@ class GAS:
             bound with the uploaded dataset.
 
         Raises:
-            OperationError: When uploading the dataset based on both draft number
+            ValueError: When uploading the dataset based on both draft number
                 and branch name is not allowed.
             Exception: When Exception was raised during uploading dataset.
 
@@ -606,7 +606,7 @@ class GAS:
         dataset_client = self.get_dataset(dataset.name, isinstance(dataset, FusionDataset))
 
         if draft_number and branch_name:
-            raise OperationError(
+            raise ValueError(
                 "Uploading the dataset based on both draft number and branch name is not allowed"
             )
 
@@ -616,10 +616,9 @@ class GAS:
         else:
             target_branch_name = branch_name if branch_name else dataset_client.status.branch_name
 
-            for draft in dataset_client.list_drafts():
-                if draft.branch_name == target_branch_name:
-                    dataset_client.checkout(draft_number=draft.number)
-                    break
+            drafts = dataset_client.list_drafts(branch_name=target_branch_name)
+            if drafts:
+                dataset_client.checkout(draft_number=drafts[0].number)
             else:
                 dataset_client.create_draft(
                     'Draft autogenerated by "GAS.upload_dataset"', branch_name=target_branch_name
