@@ -28,7 +28,7 @@ _T = TypeVar("_T")
 PagingGenerator = Callable[[int, int], Generator[_T, None, int]]
 
 
-class LazyItem(Generic[_T]):  # pylint: disable=too-few-public-methods
+class LazyItem(Generic[_T]):
     """In paging lazy evaluation system, a LazyItem instance represents an element in a pagination.
 
     If user wants to access the elememt, LazyItem will trigger the paging request to pull a page of
@@ -101,7 +101,7 @@ class LazyItem(Generic[_T]):  # pylint: disable=too-few-public-methods
 _R = TypeVar("_R")
 
 
-class ReturnGenerator(Generic[_T, _R]):  # pylint: disable=too-few-public-methods
+class ReturnGenerator(Generic[_T, _R]):
     """ReturnGenerator is a generator wrap to get the return value easily.
 
     Arguments:
@@ -121,7 +121,7 @@ class ReturnGenerator(Generic[_T, _R]):  # pylint: disable=too-few-public-method
         self.value = yield from self._generator
 
 
-class LazyPage(Generic[_T]):  # pylint: disable=too-few-public-methods
+class LazyPage(Generic[_T]):
     """In paging lazy evaluation system, a LazyPage instance represents a page with elements.
 
     LazyPage is used for sending paging request to pull a page of elements and storing them in
@@ -139,7 +139,7 @@ class LazyPage(Generic[_T]):  # pylint: disable=too-few-public-methods
 
     """
 
-    __slots__ = ("_offset", "_limit", "_func", "items")
+    __slots__: Tuple[str, ...] = ("_offset", "_limit", "_func", "items")
 
     def __init__(self, offset: int, limit: int, func: PagingGenerator[_T]) -> None:
         self.items: Tuple[LazyItem[_T], ...] = tuple(LazyItem.from_page(self) for _ in range(limit))
@@ -151,6 +151,34 @@ class LazyPage(Generic[_T]):  # pylint: disable=too-few-public-methods
         self._limit = limit
         self._func = func
 
+    @classmethod
+    def from_items(
+        cls,
+        offset: int,
+        limit: int,
+        func: PagingGenerator[_T],
+        item_contents: Iterable[_T],
+    ) -> "LazyPage[_T]":
+        """Create a LazyPage instance with the given items and generator function.
+
+        Arguments:
+            offset: The offset of the page.
+            limit: The limit of the page.
+            func: A paging generator function, which takes offset<int> and limit<int> as inputs and
+                returns a generator. The returned generator should yield the element user needs, and
+                return the total count of the elements in the paging request.
+            item_contents: The lazy item contents that need to be stored on this page.
+
+        Returns:
+            The LazyPage instance which stores the input items and function.
+
+        """
+        obj: "LazyPage[_T]" = object.__new__(cls)
+        obj._init(offset, limit, func)  # pylint: disable=protected-access
+        obj.items = tuple(LazyItem(obj, item) for item in item_contents)
+
+        return obj
+
     @locked
     def pull(self) -> None:
         """Send paging request to pull a page of elements and store them in :class:`LazyItem`."""
@@ -158,7 +186,7 @@ class LazyPage(Generic[_T]):  # pylint: disable=too-few-public-methods
             item.data = data
 
 
-class InitPage(LazyPage[_T]):  # pylint: disable=too-few-public-methods
+class InitPage(LazyPage[_T]):
     """In paging lazy evaluation system, InitPage is the page for initializing :class:`PagingList`.
 
     InitPage will send a paging request to pull a page of elements and storing them in different
@@ -326,7 +354,7 @@ class PagingList(MutableSequence[_T], ReprMixin):  # pylint: disable=too-many-an
         if hasattr(self, "_items"):
             paging_list._items = self._items[slicing]
         else:
-            paging_list._init_items = lambda index: paging_list._init_sliced_items(self, slicing)
+            paging_list._init_items = lambda _: paging_list._init_sliced_items(self, slicing)
 
         return paging_list
 
