@@ -46,7 +46,7 @@ def _get_allowed_methods_keyword() -> str:
 _ALLOWED_METHODS = _get_allowed_methods_keyword()
 
 
-class Config:  # pylint: disable=too-few-public-methods
+class Config:
     """This is a base class defining the concept of Request Config.
 
     Attributes:
@@ -116,7 +116,7 @@ class TimeoutHTTPAdapter(HTTPAdapter):
         return super().send(request, stream, timeout, verify, cert, proxies)
 
 
-class UserSession(Session):  # pylint: disable=too-few-public-methods
+class UserSession(Session):
     """This class defines UserSession."""
 
     def __init__(self) -> None:
@@ -157,7 +157,7 @@ class UserSession(Session):  # pylint: disable=too-few-public-methods
                 logger.error(
                     "Unexpected status code(%d)!%s", response.status_code, ResponseLogging(response)
                 )
-                raise ResponseError(response)
+                raise ResponseError(response=response)
 
             logger.debug(ResponseLogging(response))
             return response
@@ -267,9 +267,13 @@ class Client:
         except ResponseError as error:
             response = error.response
             error_code = response.json()["code"]
-            raise ResponseErrorDistributor.get(error_code, ResponseError)(response) from None
+            raise ResponseErrorDistributor.get(error_code, ResponseError)(
+                response=response
+            ) from None
 
-    def do(self, method: str, url: str, **kwargs: Any) -> Response:  # pylint: disable=invalid-name
+    def do(  # pylint: disable=function-redefined,invalid-name
+        self, method: str, url: str, **kwargs: Any
+    ) -> Response:
         """Send a request.
 
         Arguments:
