@@ -33,11 +33,11 @@ from requests_toolbelt import MultipartEncoder
 from ulid import ULID, from_timestamp
 
 from ..dataset import AuthData, Data, Frame, RemoteData
-from ..exception import FrameError, InvalidParamsError, OperationError, ResponseError
+from ..exception import FrameError, InvalidParamsError, ResponseError
 from ..label import Label
 from ..sensor.sensor import Sensor, Sensors
 from ..utility import FileMixin, chunked, locked
-from .lazy import PagingList
+from .lazy import LazyPage, PagingList
 from .requests import config
 from .status import Status
 
@@ -49,11 +49,15 @@ _MASK_KEYS = ("semantic_mask", "instance_mask", "panoptic_mask")
 
 
 class _UrlGetters:
-    def __init__(self, urls: PagingList[str]) -> None:
+    def __init__(self, urls: LazyPage[str]) -> None:
         self._urls = urls
 
     def __getitem__(self, index: int) -> Callable[[str], str]:
-        return lambda _: self._urls[index]
+        return lambda _: self._urls.items[index].get()
+
+    def update(self) -> None:
+        """Update all urls."""
+        self._urls.pull()
 
 
 class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
@@ -121,6 +125,20 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
         response = self._client.open_api_do("GET", "data/urls", self._dataset_id, params=params)
         return response.json()  # type: ignore[no-any-return]
 
+    def _list_data_details(self, offset: int = 0, limit: int = 128) -> Dict[str, Any]:
+        params: Dict[str, Any] = {
+            "segmentName": self._name,
+            "offset": offset,
+            "limit": limit,
+        }
+        params.update(self._status.get_status_info())
+
+        if config.is_internal:
+            params["isInternal"] = True
+
+        response = self._client.open_api_do("GET", "data/details", self._dataset_id, params=params)
+        return response.json()  # type: ignore[no-any-return]
+
     def _list_mask_urls(self, mask_type: str, offset: int = 0, limit: int = 128) -> Dict[str, Any]:
         params: Dict[str, Any] = {
             "segmentName": self._name,
@@ -259,20 +277,6 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
 
         self._client.open_api_do("PUT", "multi/callback", self._dataset_id, json=put_data)
 
-    def _import_cloud_file(
-        self,
-        cloud_path: str,
-        remote_path: str,
-    ) -> None:
-
-        put_data: Dict[str, Any] = {
-            "segmentName": self.name,
-            "objects": [{"cloudPath": cloud_path, "remotePath": remote_path}],
-            "deleteSource": False,
-        }
-        put_data.update(self._status.get_status_info())
-        self._client.open_api_do("PUT", "multi/cloud-callback", self._dataset_id, json=put_data)
-
     def _upload_label(self, data: Union[AuthData, Data]) -> None:
         label = data.label.dumps()
         if not label:
@@ -337,20 +341,43 @@ class SegmentClient(SegmentClientBase):
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
-    def _generate_data(
-        self, url_getters: Dict[str, _UrlGetters], offset: int = 0, limit: int = 128
-    ) -> Generator[RemoteData, None, int]:
-        response = self._list_labels(offset, limit)
-        urls = url_getters["file"]
+    def _generate_data(self, offset: int = 0, limit: int = 128) -> Generator[RemoteData, None, int]:
+        response = self._list_data_details(offset, limit)
 
-        for i, item in enumerate(response["labels"], offset):
-            data = RemoteData.from_response_body(item, _url_getter=urls[i])
+        urls = _UrlGetters(
+            LazyPage.from_items(
+                offset,
+                limit,
+                self._generate_urls,
+                (item["url"] for item in response["dataDetails"]),
+            ),
+        )
+
+        mask_urls = {}
+        for key in _MASK_KEYS:
+            mask_urls[key] = _UrlGetters(
+                LazyPage(
+                    offset,
+                    limit,
+                    lambda offset, limit, k=key: self._generate_mask_urls(  # type: ignore[misc]
+                        k.upper(), offset, limit
+                    ),
+                ),
+            )
+
+        for i, item in enumerate(response["dataDetails"]):
+            data = RemoteData.from_response_body(
+                item,
+                _url_getter=urls[i],
+                _url_updater=urls.update,
+            )
             label = data.label
             for key in _MASK_KEYS:
                 mask = getattr(label, key, None)
                 if mask:
                     # pylint: disable=protected-access
-                    mask._url_getter = url_getters[key][i]
+                    mask._url_getter = mask_urls[key][i]
+                    mask._url_updater = mask_urls[key].update
 
             yield data
 
@@ -430,9 +457,19 @@ class SegmentClient(SegmentClientBase):
 
         """
         self._status.check_authority_for_draft()
-
-        self._import_cloud_file(data.path, data.target_remote_path)
-        self._upload_label(data)
+        put_data: Dict[str, Any] = {
+            "segmentName": self.name,
+            "objects": [
+                {
+                    "cloudPath": data.path,
+                    "remotePath": data.target_remote_path,
+                    "label": data.label.dumps(),
+                }
+            ],
+            "deleteSource": False,
+        }
+        put_data.update(self._status.get_status_info())
+        self._client.open_api_do("PUT", "multi/cloud-callback", self._dataset_id, json=put_data)
 
     def copy_data(
         self,
@@ -461,7 +498,7 @@ class SegmentClient(SegmentClientBase):
 
         Raises:
             InvalidParamsError: When strategy is invalid.
-            OperationError: When the type of target_remote_paths is not equal
+            ValueError: When the type of target_remote_paths is not equal
                 with source_remote_paths.
 
         """
@@ -486,12 +523,12 @@ class SegmentClient(SegmentClientBase):
             all_target_remote_paths = list(target_remote_paths)
             all_source_remote_paths = list(source_remote_paths)
             if len(all_target_remote_paths) != len(all_source_remote_paths):
-                raise OperationError(
+                raise ValueError(
                     "To copy the data, the length of target_remote_paths "
                     "must be equal with source_remote_paths"
                 )
         else:
-            raise OperationError(
+            raise ValueError(
                 "To copy the data, the type of target_remote_paths "
                 "must be equal with source_remote_paths"
             )
@@ -547,7 +584,7 @@ class SegmentClient(SegmentClientBase):
 
         Raises:
             InvalidParamsError: When strategy is invalid.
-            OperationError: When the type or the length of target_remote_paths is not equal
+            ValueError: When the type or the length of target_remote_paths is not equal
                 with source_remote_paths.
                 Or when the dataset_id and drafter_number of source_client
                 is not equal with the current segment client.
@@ -574,12 +611,12 @@ class SegmentClient(SegmentClientBase):
             all_target_remote_paths = list(target_remote_paths)
             all_source_remote_paths = list(source_remote_paths)
             if len(all_target_remote_paths) != len(all_source_remote_paths):
-                raise OperationError(
+                raise ValueError(
                     "To move the data, the length of target_remote_paths "
                     "must be equal with source_remote_paths"
                 )
         else:
-            raise OperationError(
+            raise ValueError(
                 "To move the data, the type of target_remote_paths "
                 "must be equal with source_remote_paths"
             )
@@ -593,7 +630,7 @@ class SegmentClient(SegmentClientBase):
             ):
                 source["segmentName"] = source_client.name
             else:
-                raise OperationError(
+                raise ValueError(
                     "To move the data, the dataset_id and drafter_number of source_client "
                     "must be equal with the current segment client"
                 )
@@ -632,13 +669,7 @@ class SegmentClient(SegmentClientBase):
             The PagingList of :class:`~tensorbay.dataset.data.RemoteData`.
 
         """
-        url_getters = {"file": _UrlGetters(self.list_urls())}
-        for key in _MASK_KEYS:
-            url_getters[key] = _UrlGetters(self.list_mask_urls(key.upper()))
-
-        return PagingList(
-            lambda offset, limit: self._generate_data(url_getters, offset, limit), 128
-        )
+        return PagingList(self._generate_data, 128)
 
     def delete_data(self, remote_path: str) -> None:
         """Delete data of a segment in a certain commit with the given remote paths.
@@ -699,13 +730,21 @@ class FusionSegmentClient(SegmentClientBase):
     def __init__(self, name: str, data_client: "FusionDatasetClient") -> None:
         super().__init__(name, data_client)
 
-    def _generate_frames(
-        self, urls: PagingList[Dict[str, str]], offset: int = 0, limit: int = 128
-    ) -> Generator[Frame, None, int]:
-        response = self._list_labels(offset, limit)
+    def _generate_frames(self, offset: int = 0, limit: int = 128) -> Generator[Frame, None, int]:
+        response = self._list_data_details(offset, limit)
 
-        for index, item in enumerate(response["labels"], offset):
-            yield Frame.from_response_body(item, index, urls)
+        url_page = LazyPage.from_items(
+            offset,
+            limit,
+            self._generate_urls,
+            (
+                {frame["sensorName"]: frame["url"] for frame in item["frame"]}
+                for item in response["dataDetails"]
+            ),
+        )
+
+        for index, item in enumerate(response["dataDetails"]):
+            yield Frame.from_response_body(item, index, url_page)
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
@@ -829,8 +868,7 @@ class FusionSegmentClient(SegmentClientBase):
             The PagingList of :class:`~tensorbay.dataset.frame.Frame`.
 
         """
-        urls = self.list_urls()
-        return PagingList(lambda offset, limit: self._generate_frames(urls, offset, limit), 128)
+        return PagingList(self._generate_frames, 128)
 
     def delete_frame(self, frame_id: Union[str, ULID]) -> None:
         """Delete a frame of a segment in a certain commit with the given frame id.
