@@ -7,7 +7,7 @@
 
 from typing import TYPE_CHECKING, Any, Dict, Generator, Optional, Union
 
-from ..exception import OperationError, ResourceNotExistError, StatusError
+from ..exception import ResourceNotExistError, StatusError
 from .lazy import PagingList
 from .status import Status
 from .struct import Branch, Commit, Draft, Tag
@@ -63,8 +63,10 @@ class VersionControlClient:
         response = self._client.open_api_do("POST", "commits", self._dataset_id, json=post_data)
         return response.json()["commitId"]  # type: ignore[no-any-return]
 
-    def _generate_drafts(self, offset: int = 0, limit: int = 128) -> Generator[Draft, None, int]:
-        params = {"offset": offset, "limit": limit}
+    def _generate_drafts(
+        self, status: Optional[str], branch_name: Optional[str], offset: int = 0, limit: int = 128
+    ) -> Generator[Draft, None, int]:
+        params = {"offset": offset, "limit": limit, "status": status, "branchName": branch_name}
         response = self._client.open_api_do("GET", "drafts", self._dataset_id, params=params).json()
 
         for item in response["drafts"]:
@@ -72,12 +74,14 @@ class VersionControlClient:
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
+    def _close_draft(self, number: int) -> None:
+        patch_data = {"status": "CLOSED"}
+        self._client.open_api_do("PATCH", f"drafts/{number}", self._dataset_id, json=patch_data)
+
     def _generate_commits(
-        self, revision: Optional[str] = None, offset: int = 0, limit: int = 128
+        self, revision: str, offset: int = 0, limit: int = 128
     ) -> Generator[Commit, None, int]:
-        params: Dict[str, Any] = {"offset": offset, "limit": limit}
-        if revision:
-            params["commit"] = revision
+        params: Dict[str, Any] = {"offset": offset, "limit": limit, "commit": revision}
 
         response = self._client.open_api_do(
             "GET", "commits", self._dataset_id, params=params
@@ -269,14 +273,24 @@ class VersionControlClient:
 
         raise ResourceNotExistError(resource="draft", identification=draft_number)
 
-    def list_drafts(self) -> PagingList[Draft]:
+    def list_drafts(
+        self, status: Optional[str] = "OPEN", branch_name: Optional[str] = None
+    ) -> PagingList[Draft]:
         """List all the drafts.
 
+        Arguments:
+            status: The draft status which includes "OPEN", "CLOSED", "COMMITTED", "ALL" and None.
+                    where None means listing open drafts.
+            branch_name: The branch name.
+
         Returns:
             The PagingList of :class:`drafts<.Draft>`.
 
         """
-        return PagingList(self._generate_drafts, 128)
+        return PagingList(
+            lambda offset, limit: self._generate_drafts(status, branch_name, offset, limit),
+            128,
+        )
 
     def update_draft(
         self,
@@ -309,21 +323,20 @@ class VersionControlClient:
             "PATCH", f"drafts/{draft_number}", self._dataset_id, json=patch_data
         )
 
-    def close_draft(self, draft_number: Optional[int] = None) -> None:
+    def close_draft(self, number: int) -> None:
         """Close the draft.
 
         Arguments:
-            draft_number: The closed draft number.
-                If is not given, close the current draft.
-        """
-        if draft_number is None:
-            self._status.check_authority_for_draft()
-            draft_number = self.status.draft_number
+            number: The draft number.
 
-        patch_data = {"status": "CLOSED"}
-        self._client.open_api_do(
-            "PATCH", f"drafts/{draft_number}", self._dataset_id, json=patch_data
-        )
+        Raises:
+            StatusError: When closing the current draft.
+
+        """
+        if number == self.status.draft_number:
+            raise StatusError("Closing the current draft is not allowed")
+
+        self._close_draft(number)
 
     def get_commit(self, revision: Optional[str] = None) -> Commit:
         """Get the certain commit with the given revision.
@@ -367,12 +380,27 @@ class VersionControlClient:
                 If is given, list the commits before the given commit.
                 If is not given, list the commits before the current commit.
 
+        Raises:
+            TypeError: When the given revision is illegal.
+
         Returns:
             The PagingList of :class:`commits<.Commit>`.
 
         """
+        if revision is None:
+            if self.status.is_draft:
+                revision = self._status.branch_name
+            else:
+                revision = self._status.commit_id
+
+        if not revision:
+            raise TypeError("The given revision is illegal")
+
         return PagingList(
-            lambda offset, limit: self._generate_commits(revision, offset, limit), 128
+            lambda offset, limit: self._generate_commits(
+                revision, offset, limit  # type: ignore[arg-type]
+            ),
+            128,
         )
 
     def create_branch(self, name: str, revision: Optional[str] = None) -> None:
@@ -444,11 +472,11 @@ class VersionControlClient:
             name: The name of the branch to be deleted.
 
         Raises:
-            OperationError: When deleting the current branch.
+            StatusError: When deleting the current branch.
 
         """
         if name == self.status.branch_name:
-            raise OperationError("Deleting the current branch is not allowed")
+            raise StatusError("Deleting the current branch is not allowed")
 
         self._delete_branch(name)
 
