@@ -19,8 +19,9 @@ from uuid import UUID
 
 from ulid import ULID, from_str, from_uuid
 
-from ..utility import UserMutableMapping, common_loads
-from .data import DataBase
+from ..client.lazy import LazyPage
+from ..utility import UserMutableMapping
+from .data import DataBase, RemoteData
 
 logger = logging.getLogger(__name__)
 
@@ -61,33 +62,14 @@ class Frame(UserMutableMapping[str, "DataBase._Type"]):
 
         return self.__class__.__name__
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        self._data = {}
-        if "frameId" in contents:
-            try:
-                self.frame_id = from_str(contents["frameId"])
-            except ValueError:
-                # Legacy fusion dataset use uuid as frame ID
-                # Keep this code here to make SDK compatible with uuid
-                self.frame_id = from_uuid(UUID(contents["frameId"]))
-                if self.__class__._logger_flag:  # pylint: disable=protected-access
-                    self.__class__._logger_flag = False  # pylint: disable=protected-access
-                    logger.warning(
-                        "WARNING: This is a legacy fusion dataset which use uuid as frame ID, "
-                        "it should be updated to ulid."
-                    )
-
-        for data_contents in contents["frame"]:
-            self._data[data_contents["sensorName"]] = DataBase.loads(data_contents)
-
-        # self._pose = Transform3D.loads(contents["pose"]) if "pose" in contents else None
-
     @classmethod
-    def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
-        """Loads a :class:`Frame` object from a dict containing the frame information.
+    def from_response_body(
+        cls: Type[_T], body: Dict[str, Any], url_index: int, urls: LazyPage[Dict[str, str]]
+    ) -> _T:
+        """Loads a :class:`Frame` object from a response body.
 
         Arguments:
-            contents: A dict containing the information of a frame,
+            body: The response body which contains the information of a frame,
                 whose format should be like::
 
                     {
@@ -95,20 +77,45 @@ class Frame(UserMutableMapping[str, "DataBase._Type"]):
                         "frame": [
                             {
                                 "sensorName": <str>,
-                                "remotePath" or "localPath": <str>,
+                                "remotePath": <str>,
                                 "timestamp": <float>,
+                                "url": <str>,
                                 "label": {...}
                             },
                             ...
                             ...
                         ]
                     }
+            url_index: The index of the url.
+            urls: A sequence of mappings which key is the sensor name and value is the url.
 
         Returns:
             The loaded :class:`Frame` object.
 
-        """
-        return common_loads(cls, contents)
+        """  # noqa: DAR101  # https://github.com/terrencepreilly/darglint/issues/120
+        try:
+            frame_id = from_str(body["frameId"])
+        except ValueError:
+            # Legacy fusion dataset use uuid as frame ID
+            # Keep this code here to make SDK compatible with uuid
+            frame_id = from_uuid(UUID(body["frameId"]))
+            if cls._logger_flag:  # pylint: disable=protected-access
+                cls._logger_flag = False  # pylint: disable=protected-access
+                logger.warning(
+                    "WARNING: This is a legacy fusion dataset which use uuid as frame ID, "
+                    "it should be updated to ulid."
+                )
+        frame = cls(frame_id)
+        for data_contents in body["frame"]:
+            sensor_name = data_contents["sensorName"]
+            frame[sensor_name] = RemoteData.from_response_body(
+                data_contents,
+                _url_getter=lambda _, s=sensor_name: urls.items[  # type: ignore[misc]
+                    url_index
+                ].get()[s],
+                _url_updater=urls.pull,
+            )
+        return frame
 
     # @property
     # def pose(self) -> Optional[Transform3D]:
@@ -121,29 +128,6 @@ class Frame(UserMutableMapping[str, "DataBase._Type"]):
     #     """
     #     return self._pose
 
-    def dumps(self) -> Dict[str, Any]:
-        """Dumps the current frame into a dict.
-
-        Returns:
-            A dict containing all the information of the frame.
-
-        """
-        contents: Dict[str, Any] = {}
-        # if self._pose:
-        #     contents["pose"] = self._pose.dumps()
-        if hasattr(self, "frame_id"):
-            contents["frameId"] = str(self.frame_id)
-
-        frame = []
-        for sensor_name, data in self._data.items():
-            data_contents = {"sensorName": sensor_name}
-            data_contents.update(data.dumps())
-            frame.append(data_contents)
-
-        contents["frame"] = frame
-
-        return contents
-
     # def set_pose(
     #     self,
     #     translation: Optional[Iterable[float]] = (0, 0, 0),
