@@ -28,8 +28,8 @@ The class hierarchy for TensorBay custom exceptions is::
              +-- NoFileError
              +-- FileStructureError
 
-:class:`ResponseSystemError` is deprecated since version v1.11.0.
-It will be removed in version v1.13.0. Use :class:`InternalServerError` instead.
+:class:`OperationError` is removed in version v1.13.0.
+Use :class:`StatusError` or :class:`ValueError` instead.
 
 """
 
@@ -107,10 +107,6 @@ class FrameError(ClientError):
     """This class defines the exception for incorrect frame id."""
 
 
-class OperationError(ClientError):
-    """This class defines the exception for incorrect operation."""
-
-
 class ResponseError(ClientError):
     """This class defines the exception for post response error.
 
@@ -273,9 +269,6 @@ class InternalServerError(ResponseError):
     STATUS_CODE = 500
 
 
-ResponseSystemError = InternalServerError
-
-
 class UnauthorizedError(ResponseError):
     """This class defines the exception for unauthorized response error."""
 
