@@ -8,13 +8,16 @@
 from .AADB import AADB
 from .AnimalPose import AnimalPose5, AnimalPose7
 from .AnimalsWithAttributes2 import AnimalsWithAttributes2
-from .BDD100K import BDD100K
+from .BDD100K import BDD100K, BDD100K_10K
+from .BDD100K_MOT2020 import BDD100K_MOT2020, BDD100K_MOTS2020
 from .BioIDFace import BioIDFace
 from .BSTLD import BSTLD
 from .CACD import CACD
 from .CADC import CADC
 from .CarConnection import CarConnection
 from .CCPD import CCPD, CCPDGreen
+from .CIHP import CIHP
+from .COCO2017 import COCO2017
 from .CoinImage import CoinImage
 from .CompCars import CompCars
 from .COVID_CT import COVID_CT
@@ -34,13 +37,19 @@ from .JHU_CROWD import JHU_CROWD
 from .KenyanFood import KenyanFoodOrNonfood, KenyanFoodType
 from .KylbergTexture import KylbergTexture
 from .LeedsSportsPose import LeedsSportsPose
+from .LIP import LIP
 from .LISATrafficLight import LISATrafficLight
 from .LISATrafficSign import LISATrafficSign
 from .NeolixOD import NeolixOD
 from .Newsgroups20 import Newsgroups20
 from .NightOwls import NightOwls
+from .nuImages import nuImages
 from .nuScenes import nuScenes
+from .OxfordIIITPet import OxfordIIITPet
+from .PASCALContext import PASCALContext
 from .RP2K import RP2K
+from .SegTrack import SegTrack
+from .SegTrack2 import SegTrack2
 from .SVHN import SVHN
 from .THCHS30 import THCHS30
 from .THUCNews import THUCNews
@@ -48,6 +57,7 @@ from .TLR import TLR
 from .UAVDT import UAVDT
 from .VOC2012ActionClassification import VOC2012ActionClassification
 from .VOC2012Detection import VOC2012Detection
+from .VOC2012Segmentation import VOC2012Segmentation
 from .WIDER_FACE import WIDER_FACE
 
 __all__ = [
@@ -58,12 +68,17 @@ __all__ = [
     "AnimalsWithAttributes2",
     "BioIDFace",
     "BDD100K",
+    "BDD100K_MOT2020",
+    "BDD100K_MOTS2020",
+    "BDD100K_10K",
     "BSTLD",
     "CACD",
     "CADC",
     "CarConnection",
     "CCPD",
     "CCPDGreen",
+    "CIHP",
+    "COCO2017",
     "CoinImage",
     "COVIDChestXRay",
     "CompCars",
@@ -84,14 +99,20 @@ __all__ = [
     "KenyanFoodOrNonfood",
     "KenyanFoodType",
     "KylbergTexture",
+    "LIP",
     "LISATrafficLight",
     "LISATrafficSign",
     "LeedsSportsPose",
     "NeolixOD",
     "Newsgroups20",
     "NightOwls",
+    "OxfordIIITPet",
+    "PASCALContext",
     "RP2K",
+    "SegTrack",
+    "SegTrack2",
     "SVHN",
+    "nuImages",
     "THCHS30",
     "THUCNews",
     "TLR",
@@ -100,4 +121,5 @@ __all__ = [
     "COVID_CT",
     "VOC2012Detection",
     "VOC2012ActionClassification",
+    "VOC2012Segmentation",
 ]
